Module Name:    src
Committed By:   matt
Date:           Wed Dec 22 05:53:38 UTC 2010

Modified Files:
        src/sys/arch/mips/mips [matt-nb5-mips64]: cpu_subr.c

Log Message:
Allocate page from anywhere in KSEG0, not just the first 256MB.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.12 -r1.1.2.13 src/sys/arch/mips/mips/cpu_subr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/mips/mips/cpu_subr.c
diff -u src/sys/arch/mips/mips/cpu_subr.c:1.1.2.12 src/sys/arch/mips/mips/cpu_subr.c:1.1.2.13
--- src/sys/arch/mips/mips/cpu_subr.c:1.1.2.12	Wed Sep  1 00:59:42 2010
+++ src/sys/arch/mips/mips/cpu_subr.c	Wed Dec 22 05:53:38 2010
@@ -32,7 +32,7 @@
 #include "opt_multiprocessor.h"
 #include "opt_sa.h"
 
-__KERNEL_RCSID(0, "$NetBSD: cpu_subr.c,v 1.1.2.12 2010/09/01 00:59:42 matt Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cpu_subr.c,v 1.1.2.13 2010/12/22 05:53:38 matt Exp $");
 
 #include <sys/param.h>
 #include <sys/cpu.h>
@@ -97,11 +97,11 @@
 	int error;
 
 	/*
 	* Grab a page from the first 256MB to use to store
 	* exception vectors and cpu_info for this cpu.
 	*/
 	error = uvm_pglistalloc(PAGE_SIZE,
-	    0, 0x10000000,
+	    0, MIPS_KSEG1_START - MIPS_KSEG0_START,
 	    PAGE_SIZE, PAGE_SIZE, &pglist, 1, false);
 	if (error)
 		return NULL;
@@ -507,7 +507,9 @@
 cpu_signotify(struct lwp *l)
 {
 	KASSERT(kpreempt_disabled());
+#ifdef __HAVE_FAST_SOFTINTS
 	KASSERT(lwp_locked(l, NULL));
+#endif
 	KASSERT(l->l_stat == LSONPROC || l->l_stat == LSRUN || l->l_stat == LSSTOP);
 
 	l->l_md.md_astpending = 1; 		/* force call to ast() */
@@ -97,11 +97,11 @@
 
 	/*
-	* Grab a page from the first 256MB to use to store
+	* Grab a page from the first 512MB (mappable by KSEG0) to use to store
 	* exception vectors and cpu_info for this cpu.
 	*/

Reply via email to